
# Slot: all_of


holds if all of the expressions hold

URI: [linkml:type_expression_all_of](https://w3id.org/linkml/type_expression_all_of)


## Domain and Range

[TypeExpression](TypeExpression.md) &#8594;  <sub>0..\*</sub> [AnonymousTypeExpression](AnonymousTypeExpression.md)

## Parents

 *  is_a: [all_of](all_of.md)

## Children


## Used by

 * [AnonymousTypeExpression](AnonymousTypeExpression.md)
 * [TypeDefinition](TypeDefinition.md)
 * [TypeExpression](TypeExpression.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | sh:and |

